@@ -41,10 +41,7 @@ impl TryFrom<AttributeArgs> for Args {
     fn try_from(input: AttributeArgs) -> Result<Self, Self::Error> {
         let mut paths = vec![];
         for arg in input {
-            match arg {
-                NestedMeta::Lit(Lit::Str(lit)) => paths.push(lit),
-                _ => {}
-            }
+            if let NestedMeta::Lit(Lit::Str(lit)) = arg { paths.push(lit) }
         };
         Ok(Self { paths })
     }
@@ -166,7 +163,7 @@ mod apps_tests {
 
         #[test]
         fn should_accept_str_app() {
-            let path = Lit::Str(LitStr::new("stubr-producer", Span::call_site()));
+            let path = Lit::Str(LitStr::new("stub-producer", Span::call_site()));
             let args = vec![NestedMeta::from(path)];
             let transformed = apps_transform(args, quote! { fn a() {} });
             assert!(transformed.is_ok())
